@@ -23,12 +23,16 @@ class BaseApplication:
     def __init__(self, **kwargs):
 
         kwargs = self.apply_defaults(**kwargs)
-
+        self.plot_result = False
         self._h5file = None
         self._workspace = None
+        self.figure = None
         self._file_browser = FileChooser()
         self._ga_group_name = Text(
-            value="", description="To Group", continuous_update=False
+            value="",
+            description="Group:",
+            continuous_update=False,
+            style={"description_width": "initial"},
         )
         self._ga_group = None
         self._file_browser._select.on_click(self.file_browser_change)
@@ -44,11 +48,10 @@ class BaseApplication:
             self.create_copy()
 
         self._copy_trigger.on_click(create_copy)
-        self.project_panel = HBox(
+        self.project_panel = VBox(
             [
                 Label("Workspace", style={"description_width": "initial"}),
-                self._file_browser,
-                self._copy_trigger,
+                HBox([self._file_browser, self._copy_trigger,]),
             ]
         )
         self._live_link = Checkbox(
@@ -57,11 +60,7 @@ class BaseApplication:
             indent=False,
             style={"description_width": "initial"},
         )
-
-        def live_link_choice(_):
-            self.live_link_choice()
-
-        self._live_link.observe(live_link_choice)
+        self._live_link.observe(self.live_link_choice)
         self._export_directory = FileChooser(show_only_dirs=True)
         self.live_link_panel = VBox([self.live_link])
         self._refresh = ToggleButton(value=False)
@@ -73,9 +72,15 @@ class BaseApplication:
             icon="check",
         )
 
-        self.trigger_panel = VBox(
+        self.output_panel = VBox(
             [VBox([self.trigger, self.ga_group_name]), self.live_link_panel]
         )
+        self.monitoring_panel = VBox(
+            [
+                Label("Monitoring folder", style={"description_width": "initial"}),
+                self.export_directory,
+            ]
+        )
         self.__populate__(**kwargs)
 
         def ga_group_name_update(_):
@@ -83,6 +88,11 @@ class BaseApplication:
 
         self.ga_group_name.observe(ga_group_name_update)
 
+        self._main = VBox([self.project_panel, self.output_panel])
+
+    def __call__(self):
+        return self._main
+
     def __populate__(self, **kwargs):
         for key, value in kwargs.items():
             if hasattr(self, "_" + key) or hasattr(self, key):
@@ -107,7 +117,7 @@ class BaseApplication:
         """
         Add defaults to the kwargs
         """
-        for key, value in self.defaults.items():
+        for key, value in self.defaults.copy().items():
             if key in kwargs.keys():
                 continue
             else:
@@ -148,7 +158,7 @@ class BaseApplication:
             path.join(self.export_directory.selected_path, temp_geoh5),
         )
 
-    def live_link_choice(self):
+    def live_link_choice(self, _):
         """
         Enable the monitoring folder
         """
@@ -162,16 +172,16 @@ class BaseApplication:
                 self.export_directory._set_form_values(live_path, "")
                 self.export_directory._apply_selection()
 
-            self.live_link_panel.children = [
-                self.live_link,
-                Label("Monitoring folder", style={"description_width": "initial"}),
-                self.export_directory,
-            ]
+            self.live_link_panel.children = [self.live_link, self.monitoring_panel]
         else:
             self.live_link_panel.children = [self.live_link]
 
-    def widget(self):
-        ...
+    @property
+    def main(self):
+        """
+        :obj:`ipywidgets.VBox`: A box containing all widgets forming the application.
+        """
+        return self._main
 
     @property
     def copy_trigger(self):
@@ -272,10 +282,6 @@ class BaseApplication:
         """
         return self._trigger
 
-    @property
-    def widget(self):
-        ...
-
     @property
     def workspace(self):
         """
