@@ -36,12 +36,11 @@ class ChannelOptions:
 
         self._active = Checkbox(value=False, indent=True, description="Active",)
         self._label = widgets.Text(description=description)
-        self._channel_selection = Dropdown(description="Data Channel:")
+        self._channel_selection = Dropdown(description="Channel <=> Data:")
         self._channel_selection.header = key
         self._uncertainties = widgets.Text(description="Error (%, floor)")
         self._offsets = widgets.Text(description="Offsets (x,y,z)")
-
-        self._widget = VBox(
+        self._main = VBox(
             [
                 self._active,
                 self._label,
@@ -83,8 +82,8 @@ class ChannelOptions:
         return self._offsets
 
     @property
-    def widget(self):
-        return self._widget
+    def main(self):
+        return self._main
 
 
 class SensorOptions(ObjectDataSelection):
@@ -110,13 +109,8 @@ class SensorOptions(ObjectDataSelection):
             "sensor location + (dx, dy, dz)": self._offset,
             "topo + radar + (dx, dy, dz)": VBox([self._offset, self._data]),
         }
-
-        def update_options(_):
-            self.update_options()
-
-        self.options.observe(update_options, names="value")
-        self._widget = VBox([self.options, self.option_list[self.options.value]])
-
+        self.options.observe(self.update_options, names="value")
+        self._main = VBox([self.options, self.option_list[self.options.value]])
         self._data.description = "Radar (Optional):"
         self._data.style = {"description_width": "initial"}
         self.update_data_list(None)
@@ -129,8 +123,8 @@ class SensorOptions(ObjectDataSelection):
     def options(self):
         return self._options
 
-    def update_options(self):
-        self._widget.children = [
+    def update_options(self, _):
+        self._main.children = [
             self.options,
             self.option_list[self.options.value],
         ]
@@ -155,12 +149,10 @@ class MeshOctreeOptions:
         self._padding_distance = widgets.Text(
             value="0, 0, 0, 0, 0, 0", description="Padding [W,E,N,S,D,U] (m)",
         )
-
         self._max_distance = FloatText(
             value=1000, description="Max triangulation length",
         )
-
-        self._widget = widgets.VBox(
+        self._main = widgets.VBox(
             [
                 Label("Octree Mesh"),
                 self._core_cell_size,
@@ -208,8 +200,8 @@ class MeshOctreeOptions:
         return self._padding_distance
 
     @property
-    def widget(self):
-        return self._widget
+    def main(self):
+        return self._main
 
 
 class Mesh1DOptions:
@@ -221,17 +213,11 @@ class Mesh1DOptions:
         self._hz_expansion = FloatText(value=1.05, description="Expansion factor:",)
         self._hz_min = FloatText(value=10.0, description="Smallest cell (m):",)
         self._n_cells = FloatText(value=25.0, description="Number of cells:",)
-
         self.cell_count = Label(f"Max depth: {self.count_cells():.2f} m")
-
-        def update_hz_count(_):
-            self.update_hz_count()
-
-        self.n_cells.observe(update_hz_count)
-        self.hz_expansion.observe(update_hz_count)
-        self.hz_min.observe(update_hz_count)
-
-        self._widget = VBox(
+        self.n_cells.observe(self.update_hz_count)
+        self.hz_expansion.observe(self.update_hz_count)
+        self.hz_min.observe(self.update_hz_count)
+        self._main = VBox(
             [
                 Label("1D Mesh"),
                 self.hz_min,
@@ -257,7 +243,7 @@ class Mesh1DOptions:
             self.hz_min.value * self.hz_expansion.value ** np.arange(self.n_cells.value)
         ).sum()
 
-    def update_hz_count(self):
+    def update_hz_count(self, _):
         self.cell_count.value = f"Max depth: {self.count_cells():.2f} m"
 
     @property
@@ -282,8 +268,8 @@ class Mesh1DOptions:
         return self._n_cells
 
     @property
-    def widget(self):
-        return self._widget
+    def main(self):
+        return self._main
 
 
 class ModelOptions(ObjectDataSelection):
@@ -297,11 +283,7 @@ class ModelOptions(ObjectDataSelection):
         self._options = widgets.RadioButtons(
             options=["Model", "Value"], value="Value", disabled=False,
         )
-
-        def update_panel(_):
-            self.update_panel()
-
-        self._options.observe(update_panel, names="value")
+        self._options.observe(self.update_panel, names="value")
         self.objects.description = "Object"
         self.data.description = "Values"
         self._value = FloatText(description=self.units)
@@ -309,21 +291,21 @@ class ModelOptions(ObjectDataSelection):
 
         super().__init__(**kwargs)
 
-        self.selection_widget = self.widget
-        self._widget = widgets.VBox(
+        self.selection_widget = self.main
+        self._main = widgets.VBox(
             [self._description, widgets.VBox([self._options, self._value])]
         )
 
-    def update_panel(self):
+    def update_panel(self, _):
 
         if self._options.value == "Model":
-            self._widget.children[1].children = [self._options, self.selection_widget]
-            self._widget.children[1].children[1].layout.visibility = "visible"
+            self._main.children[1].children = [self._options, self.selection_widget]
+            self._main.children[1].children[1].layout.visibility = "visible"
         elif self._options.value == "Value":
-            self._widget.children[1].children = [self._options, self._value]
-            self._widget.children[1].children[1].layout.visibility = "visible"
+            self._main.children[1].children = [self._options, self._value]
+            self._main.children[1].children[1].layout.visibility = "visible"
         else:
-            self._widget.children[1].children[1].layout.visibility = "hidden"
+            self._main.children[1].children[1].layout.visibility = "hidden"
 
     @property
     def description(self):
@@ -346,10 +328,6 @@ class ModelOptions(ObjectDataSelection):
     def value(self):
         return self._value
 
-    @property
-    def widget(self):
-        return self._widget
-
 
 class InversionOptions(BaseApplication):
     """
@@ -363,7 +341,6 @@ class InversionOptions(BaseApplication):
         self._output_name = widgets.Text(
             value="Inversion_", description="Save to:", disabled=False
         )
-
         self._chi_factor = FloatText(
             value=1, description="Target misfit", disabled=False
         )
@@ -377,7 +354,6 @@ class InversionOptions(BaseApplication):
         )
         self._lower_bound = widgets.Text(value=None, description="Lower bound value",)
         self._upper_bound = widgets.Text(value=None, description="Upper bound value",)
-
         self._ignore_values = widgets.Text(
             value="<0",
             tooltip="Dummy value",
@@ -399,12 +375,7 @@ class InversionOptions(BaseApplication):
             description="Starting tradeoff (beta):",
         )
         self._beta_start = FloatText(value=1e2, description="phi_d/phi_m")
-
-        def initial_beta_change(_):
-            self.initial_beta_change()
-
-        self._beta_start_options.observe(initial_beta_change)
-
+        self._beta_start_options.observe(self.initial_beta_change)
         self._beta_start_panel = HBox([self._beta_start_options, self._beta_start])
         self._optimization = VBox(
             [
@@ -418,12 +389,10 @@ class InversionOptions(BaseApplication):
             ]
         )
         self._starting_model = ModelOptions(**kwargs)
-
         self._susceptibility_model = ModelOptions(
             units="SI", description="Background susceptibility", **kwargs
         )
         self._susceptibility_model.options.options = ["None", "Model", "Value"]
-
         self._reference_model = ModelOptions(**kwargs)
         self._reference_model.options.options = [
             "None",
@@ -431,12 +400,7 @@ class InversionOptions(BaseApplication):
             "Model",
             "Value",
         ]
-
-        def update_ref(_):
-            self.update_ref()
-
-        self.reference_model.options.observe(update_ref)
-
+        self.reference_model.options.observe(self.update_ref)
         self._alphas = widgets.Text(
             value="1, 1, 1, 1", description="Scaling alpha_(s, x, y, z)",
         )
@@ -445,18 +409,18 @@ class InversionOptions(BaseApplication):
             description="Norms p_(s, x, y, z)",
             continuous_update=False,
         )
-
+        self.bound_panel = VBox([self._upper_bound, self._lower_bound])
         self._mesh = MeshOctreeOptions()
         self.inversion_options = {
             "output name": self._output_name,
             "uncertainties": self._uncert_mode,
-            "starting model": self._starting_model.widget,
-            "background susceptibility": self._susceptibility_model.widget,
+            "starting model": self._starting_model.main,
+            "background susceptibility": self._susceptibility_model.main,
             "regularization": VBox(
-                [self._reference_model.widget, self._alphas, self._norms]
+                [self._reference_model.main, self._alphas, self._norms]
             ),
-            "upper-lower bounds": VBox([self._upper_bound, self._lower_bound]),
-            "mesh": self.mesh.widget,
+            "upper-lower bounds": self.bound_panel,
+            "mesh": self.mesh.main,
             "ignore values": VBox([self._ignore_values, self._air_values]),
             "optimization": self._optimization,
         }
@@ -465,15 +429,11 @@ class InversionOptions(BaseApplication):
             value=list(self.inversion_options.keys())[0],
             disabled=False,
         )
-
-        def inversion_option_change(_):
-            self.inversion_option_change()
-
-        self.option_choices.observe(inversion_option_change, names="value")
+        self.option_choices.observe(self.inversion_option_change, names="value")
 
         super().__init__(**self.apply_defaults(**kwargs))
 
-        self._widget = widgets.VBox(
+        self._main = widgets.VBox(
             [
                 HBox([widgets.Label("Inversion Options")]),
                 HBox(
@@ -486,17 +446,13 @@ class InversionOptions(BaseApplication):
             layout=Layout(width="100%"),
         )
 
-        for obj in self.__dict__:
-            if hasattr(getattr(self, obj), "style"):
-                getattr(self, obj).style = {"description_width": "initial"}
-
-    def inversion_option_change(self):
-        self._widget.children[1].children = [
+    def inversion_option_change(self, _):
+        self._main.children[1].children = [
             self.option_choices,
             self.inversion_options[self.option_choices.value],
         ]
 
-    def initial_beta_change(self):
+    def initial_beta_change(self, _):
         if self._beta_start_options.value == "ratio":
             self._beta_start.description = "phi_d/phi_m"
         else:
@@ -592,14 +548,7 @@ class InversionOptions(BaseApplication):
     def uncert_mode(self):
         return self._uncert_mode
 
-    @property
-    def widget(self):
-        """
-        :obj:`ipywidgets.VBox`: Pre-defined application layout
-        """
-        return self._widget
-
-    def update_ref(self):
+    def update_ref(self, _):
         alphas = string_2_list(self.alphas.value)
         if self.reference_model.options.value == "None":
             alphas[0] = 0.0
@@ -627,9 +576,7 @@ def get_inversion_output(h5file, group_name):
             if "Iteration" in comment["Author"]:
                 out["iteration"] += [np.int(comment["Author"].split("_")[1])]
                 out["time"] += [comment["Date"]]
-
                 values = json.loads(comment["Text"])
-
                 out["phi_d"] += [np.float(values["phi_d"])]
                 out["phi_m"] += [np.float(values["phi_m"])]
                 out["beta"] += [np.float(values["beta"])]
@@ -650,13 +597,11 @@ def plot_convergence_curve(h5file):
 
     """
     workspace = Workspace(h5file)
-
     names = [
         group.name
         for group in workspace.all_groups()
         if isinstance(group, ContainerGroup)
     ]
-
     objects = widgets.Dropdown(
         options=names, value=names[0], description="Inversion Group:",
     )
@@ -758,139 +703,95 @@ class InversionApp(PlotSelection2D):
         self.data_channel_choices = widgets.Dropdown()
         self.data_channel_panel = widgets.VBox([self.data_channel_choices])
         self.survey_type_panel = VBox([self.system])
-
-        def run_trigger(_):
-            self.run_trigger()
-
-        self.run.observe(run_trigger, names="value")
-
-        def write_trigger(_):
-            self.write_trigger()
-
-        self.write.observe(write_trigger, names="value")
-
-        def system_observer(_):
-            self.system_observer()
-
-        self.system.observe(system_observer, names="value")
-
-        # def update_options(_):
-        #     self.update_options()
-        #
-        # for item in self.inversion_parameters.__dict__.values():
-        #     if isinstance(item, Widget):
-        #         item.observe(update_options)
-        #     elif isinstance(item, BaseApplication):
-        #         for val in item.__dict__.values():
-        #             if isinstance(val, Widget):
-        #                 val.observe(update_options)
-
-        # self.plot_widget.layout = Layout(width="60%")
+        self.run.observe(self.run_trigger, names="value")
+        self.write.observe(self.write_trigger, names="value")
+        self.system.observe(self.system_observer, names="value")
         self.mesh_octree = MeshOctreeOptions(**kwargs)
         self.mesh_1D = Mesh1DOptions(**kwargs)
 
         super().__init__(**kwargs)
 
-        def object_observer(_):
-            self.object_observer()
-
-        self.objects.observe(object_observer, names="value")
-
-        def update_component_panel(_):
-            self.update_component_panel()
-
-        self.data.observe(update_component_panel, names="value")
-
-        def data_channel_choices_observer(_):
-            self.data_channel_choices_observer()
-
-        self.data_channel_choices.observe(data_channel_choices_observer, names="value")
-
-        # Define widgets linked to common object
+        self.objects.observe(self.object_observer, names="value")
+        self.data.observe(self.update_component_panel, names="value")
+        self.data_channel_choices.observe(
+            self.data_channel_choices_observer, names="value"
+        )
         self.topography = TopographyOptions()
         self.topography.workspace = self._workspace
+
         if "topography" in kwargs.keys():
             self.topography.__populate__(**kwargs["topography"])
 
         self.inversion_parameters = InversionOptions()
         self.inversion_parameters.update_workspace(self._workspace)
+
         if "inversion_parameters" in kwargs.keys():
             self.inversion_parameters.__populate__(**kwargs["inversion_parameters"])
 
         self.sensor = SensorOptions()
         self.sensor.workspace = self._workspace
         self.sensor.objects = self.objects
+
         if "sensor" in kwargs.keys():
             self.sensor.__populate__(**kwargs["sensor"])
 
         self.lines = LineOptions()
         self.lines.workspace = self._workspace
         self.lines.objects = self.objects
-
-        def update_selection(_):
-            self.update_selection()
-
-        self.lines.lines.observe(update_selection, names="value")
-
-        # SPATIAL PARAMETERS DROPDOWN
+        self.lines.lines.observe(self.update_selection, names="value")
         self.spatial_options = {
-            "Topography": self.topography.widget,
-            "Sensor": self.sensor.widget,
-            "Line ID": self.lines.widget,
+            "Topography": self.topography.main,
+            "Sensor": self.sensor.main,
+            "Line ID": self.lines.main,
         }
         self.spatial_choices = widgets.Dropdown(
             options=list(self.spatial_options.keys()),
             value=list(self.spatial_options.keys())[0],
             disabled=False,
         )
-
-        def spatial_option_change(_):
-            self.spatial_option_change()
-
-        self.spatial_choices.observe(spatial_option_change, names="value")
-
+        self.spatial_choices.observe(self.spatial_option_change, names="value")
         self.spatial_panel = VBox(
             [self.spatial_choices, self.spatial_options[self.spatial_choices.value]]
         )
 
-        # Link the data extent with the octree mesh param
-        def update_octree_param(_):
-            self.update_octree_param()
-
         for item in ["width", "height", "resolution"]:
-            getattr(self, item).observe(update_octree_param, names="value")
+            getattr(self, item).observe(self.update_octree_param, names="value")
 
-        self._widget = VBox(
+        self.output_panel = VBox([self.export_directory, self.write, self.run])
+        self._main = VBox(
             [
                 self.project_panel,
                 HBox(
                     [
-                        self.widget,
+                        self.data_panel,
                         VBox(
                             [
-                                VBox([Label(""), self.survey_type_panel]),
-                                VBox([Label("Components"), self.data_channel_panel]),
+                                VBox(
+                                    [
+                                        Label("Geophysical System"),
+                                        self.survey_type_panel,
+                                    ]
+                                ),
+                                VBox([Label("Channels"), self.data_channel_panel]),
                             ],
-                            layout=Layout(width="40%"),
                         ),
                     ]
                 ),
+                self.window_selection,
                 VBox(
                     [
                         Label("Topo, Sensor and Line Location Options"),
                         self.spatial_panel,
                     ]
                 ),
-                self.inversion_parameters.widget,
+                self.inversion_parameters.main,
                 self.forward_only,
-                self.export_directory,
-                self.write,
-                self.run,
+                self.output_panel,
             ]
         )
 
-        self.object_observer()
-        self.inversion_parameters.update_ref()
+        self.object_observer(None)
+        self.inversion_parameters.update_ref(None)
 
     @property
     def data_count(self):
@@ -976,7 +877,7 @@ class InversionApp(PlotSelection2D):
         """
         return self._write
 
-    def run_trigger(self):
+    def run_trigger(self, _):
         """
 
         """
@@ -996,7 +897,7 @@ class InversionApp(PlotSelection2D):
             self.run.value = False
             self.run.button_style = ""
 
-    def system_observer(self):
+    def system_observer(self, _):
         """
         Change the application on change of system
         """
@@ -1022,9 +923,7 @@ class InversionApp(PlotSelection2D):
 
             # Switch mesh options
             self.inversion_parameters._mesh = self.mesh_octree
-            self.inversion_parameters.inversion_options[
-                "mesh"
-            ] = self.mesh_octree.widget
+            self.inversion_parameters.inversion_options["mesh"] = self.mesh_octree.main
 
             self.inversion_parameters.reference_model.options.options = [
                 "None",
@@ -1088,7 +987,7 @@ class InversionApp(PlotSelection2D):
             self.inversion_parameters.max_iterations.value = 10
             # Switch mesh options
             self.inversion_parameters._mesh = self.mesh_1D
-            self.inversion_parameters.inversion_options["mesh"] = self.mesh_1D.widget
+            self.inversion_parameters.inversion_options["mesh"] = self.mesh_1D.main
             flag = "EM1D"
 
         self.inversion_parameters.reference_model.value.description = inversion_defaults()[
@@ -1137,7 +1036,7 @@ class InversionApp(PlotSelection2D):
 
             # Trigger plot update
             if self.data_channel_choices.value == channel.header:
-                self.plotting_data = channel
+                self.plotting_data = channel.value
                 self.refresh.value = False
                 self.refresh.value = True
 
@@ -1162,7 +1061,7 @@ class InversionApp(PlotSelection2D):
 
             channel_options.channel_selection.observe(channel_setter, names="value")
 
-            data_channel_options[key] = channel_options.widget
+            data_channel_options[key] = channel_options.main
 
             if self.system.value not in ["Magnetics", "Gravity"]:
                 data_channel_options[key].children[1].value = channel
@@ -1179,7 +1078,7 @@ class InversionApp(PlotSelection2D):
                 data_channel_options[self.data_channel_choices.value],
             ]
 
-        self.update_component_panel()
+        self.update_component_panel(None)
 
         if (
             self.system.value not in ["Magnetics", "Gravity"]
@@ -1203,7 +1102,7 @@ class InversionApp(PlotSelection2D):
         else:
             self.survey_type_panel.children = [self.system]
 
-    def object_observer(self):
+    def object_observer(self, _):
 
         self.resolution.indices = None
 
@@ -1218,7 +1117,7 @@ class InversionApp(PlotSelection2D):
                 if any([specs["flag"] in channel for channel in data_list]):
                     self.system.value = aem_system
 
-            self.system_observer()
+            self.system_observer(None)
 
             if hasattr(self.data_channel_choices, "data_channel_options"):
                 for (
@@ -1246,7 +1145,7 @@ class InversionApp(PlotSelection2D):
                     data_list += [component]
         return data_list
 
-    def update_component_panel(self):
+    def update_component_panel(self, _):
         if self.workspace.get_entity(self.objects.value):
             entity = self.workspace.get_entity(self.objects.value)[0]
             data_list = self.get_data_list(entity)
@@ -1260,7 +1159,7 @@ class InversionApp(PlotSelection2D):
                     value = find_value(data_list, [key])
                     data_widget.children[2].value = value
 
-    def data_channel_choices_observer(self):
+    def data_channel_choices_observer(self, _):
         if hasattr(
             self.data_channel_choices, "data_channel_options"
         ) and self.data_channel_choices.value in (
@@ -1280,10 +1179,14 @@ class InversionApp(PlotSelection2D):
                 value = find_value(data_list, [self.data_channel_choices.value])
                 data_widget.children[2].value = value
 
+            self.plotting_data = data_widget.children[2].value
+            self.refresh.value = False
+            self.refresh.value = True
+
         self.write.button_style = "warning"
         self.run.button_style = "danger"
 
-    def spatial_option_change(self):
+    def spatial_option_change(self, _):
         self.spatial_panel.children = [
             self.spatial_choices,
             self.spatial_options[self.spatial_choices.value],
@@ -1291,7 +1194,7 @@ class InversionApp(PlotSelection2D):
         self.write.button_style = "warning"
         self.run.button_style = "danger"
 
-    def update_octree_param(self):
+    def update_octree_param(self, _):
         dl = self.resolution.value
         self.mesh_octree.core_cell_size.value = f"{dl/2:.0f}, {dl/2:.0f}, {dl/2:.0f}"
         self.mesh_octree.depth_core.value = np.ceil(
@@ -1316,12 +1219,12 @@ class InversionApp(PlotSelection2D):
         self.write.button_style = "warning"
         self.run.button_style = "danger"
 
-    def update_selection(self):
+    def update_selection(self, _):
         self.highlight_selection = {self.lines.data.value: self.lines.lines.value}
         self.refresh.value = False
         self.refresh.value = True
 
-    def write_trigger(self):
+    def write_trigger(self, _):
         if self.write.value is False:
             return
 
