@@ -3,6 +3,9 @@ from .plotting import (
     format_axis,
     plot_plan_data_selection,
     plot_profile_data_selection,
+    plotly_surface,
+    plotly_block_model,
+    plotly_scatter,
 )
 from .scatter import ScatterPlots
-from .slice import PlotSelection2D
+from .selection import PlotSelection2D
