@@ -2,7 +2,9 @@ import matplotlib.colors as colors
 import matplotlib.pyplot as plt
 import numpy as np
 from copy import copy
-from geoh5py.objects import Curve, Grid2D, Points, Surface
+import plotly.graph_objects as go
+from geoh5py.objects import Curve, Grid2D, Points, Surface, BlockModel
+from geoh5py.data import Data
 
 from geoapps.utils import (
     filter_xy,
@@ -75,8 +77,8 @@ def plot_plan_data_selection(entity, data, **kwargs):
     else:
         return axis, out, indices, line_selection, contour_set
 
-    for collection in axis.collections:
-        collection.remove()
+    # for collection in axis.collections:
+    #     collection.remove()
 
     locations = entity.vertices
     if "resolution" not in kwargs.keys():
@@ -195,11 +197,11 @@ def plot_plan_data_selection(entity, data, **kwargs):
         x = X.ravel()[ind]
         y = Y.ravel()[ind]
         if ind.sum() > 0:
-            format_labels(x, y, axis)
+            format_labels(x, y, axis, **kwargs)
             axis.set_xlim([x.min(), x.max()])
             axis.set_ylim([y.min(), y.max()])
     elif np.any(x) and np.any(y):
-        format_labels(x, y, axis)
+        format_labels(x, y, axis, **kwargs)
         axis.set_xlim([x.min(), x.max()])
         axis.set_ylim([y.min(), y.max()])
 
@@ -324,6 +326,156 @@ def plot_profile_data_selection(
     return ax, threshold
 
 
+def plotly_scatter(
+    points,
+    figure=None,
+    color=None,
+    size=None,
+    marker_scale=10.0,
+    colorscale="Portland",
+    **kwargs,
+):
+    """
+    Create a plotly.graph_objects.Mesh3D figure.
+    """
+    assert (
+        getattr(points, "vertices", None) is not None
+    ), f"Input object must have vertices"
+
+    if figure is None:
+        figure = go.FigureWidget()
+
+    figure.add_trace(go.Scatter3d())
+    figure.data[-1].x = points.vertices[:, 0]
+    figure.data[-1].y = points.vertices[:, 1]
+    figure.data[-1].z = points.vertices[:, 2]
+    figure.data[-1].mode = "markers"
+    figure.data[-1].marker = {"colorscale": colorscale}
+
+    for key, value in kwargs.items():
+        if hasattr(figure.data[-1], key):
+            setattr(figure.data[-1], key, value)
+        elif hasattr(figure.data[-1].marker, key):
+            setattr(figure.data[-1].marker, key, value)
+
+    if color is not None:
+        color = check_data_type(color)
+        figure.data[-1].marker.color = color
+
+    if size is not None:
+        size = normalize(check_data_type(size))
+        figure.data[-1].marker.size = size * marker_scale
+    else:
+        figure.data[-1].marker.size = marker_scale
+
+    figure.update_layout(scene_aspectmode="data")
+
+    return figure
+
+
+def plotly_surface(
+    surface, figure=None, intensity=None, colorscale="Portland", **kwargs
+):
+    """
+    Create a plotly.graph_objects.Mesh3D figure.
+    """
+    assert isinstance(surface, Surface), f"Input surface must be of type {Surface}"
+
+    if figure is None:
+        figure = go.FigureWidget()
+
+    figure.add_trace(go.Mesh3d())
+    figure.data[-1].x = surface.vertices[:, 0]
+    figure.data[-1].y = surface.vertices[:, 1]
+    figure.data[-1].z = surface.vertices[:, 2]
+    figure.data[-1].i = surface.cells[:, 0]
+    figure.data[-1].j = surface.cells[:, 1]
+    figure.data[-1].k = surface.cells[:, 2]
+    figure.data[-1].colorscale = colorscale
+
+    for key, value in kwargs.items():
+        if hasattr(figure.data[-1], key):
+            setattr(figure.data[-1], key, value)
+
+    if intensity is not None:
+        intensity = check_data_type(intensity)
+        figure.data[-1].intensity = intensity
+
+    figure.update_layout(scene_aspectmode="data")
+
+    return figure
+
+
+def plotly_block_model(
+    block_model,
+    figure=None,
+    value=None,
+    x_slice=[],
+    y_slice=[],
+    z_slice=[],
+    colorscale="Portland",
+    **kwargs,
+):
+    """
+    Create a plotly.graph_objects.Mesh3D figure.
+    """
+    assert isinstance(
+        block_model, BlockModel
+    ), f"Input block_model must be of type {Surface}"
+
+    if figure is None:
+        figure = go.FigureWidget()
+
+    if not x_slice:
+        x_slice = [block_model.centroids[:, 0].mean()]
+
+    if not y_slice:
+        y_slice = [block_model.centroids[:, 1].mean()]
+
+    if not z_slice:
+        z_slice = [block_model.centroids[:, 2].mean()]
+
+    figure.add_trace(go.Volume())
+    figure.data[-1].x = block_model.centroids[:, 0]
+    figure.data[-1].y = block_model.centroids[:, 1]
+    figure.data[-1].z = block_model.centroids[:, 2]
+
+    figure.data[-1].opacity = 1.0
+    figure.data[-1].slices = {
+        "x": dict(show=True, locations=x_slice),
+        "y": dict(show=True, locations=y_slice),
+        "z": dict(show=True, locations=z_slice),
+    }
+    figure.data[-1].caps = dict(x_show=False, y_show=False, z_show=False)
+    figure.data[-1].colorscale = colorscale
+
+    for key, vals in kwargs.items():
+        if hasattr(figure.data[-1], key):
+            setattr(figure.data[-1], key, vals)
+
+    if value is not None:
+        value = check_data_type(value)
+        figure.data[-1].value = value
+
+    figure.update_layout(scene_aspectmode="data")
+
+    return figure
+
+
+def check_data_type(data):
+    """
+    Take data as a list or geoh5py.data.Data type and return an array.
+    """
+    if isinstance(data, list):
+        data = data[0]
+
+    if isinstance(data, Data):
+        data = data.values
+
+    assert isinstance(data, np.ndarray), "Values must be of type numpy.ndarray"
+    return data
+
+
 # def plot_em_data_widget(h5file):
 #     workspace = Workspace(h5file)
 #
