@@ -1,8 +1,7 @@
 from .calculator import Calculator
-from .cdi_surface import CDICurve2Surface
+from .create import Surface2D, ContourValues
 from .coordinate_transformation import CoordinateTransformation
-from .contours import ContourValues
 from .data_interpolation import DataInterpolation
 from .edge_detection import EdgeDetectionApp
-from .em_profiling import EMLineProfiler
+from .peak_finder import PeakFinder
 from .clustering import Clustering
