@@ -1,75 +1,47 @@
+import re
 import numpy
 from geoh5py.workspace import Workspace
 from geoh5py.groups import RootGroup
 from ipywidgets.widgets import HBox, Layout, VBox, Text, Textarea, Button
 from geoapps.selection import ObjectDataSelection
+from geoapps.plotting import plot_plan_data_selection
 
 
 class Calculator(ObjectDataSelection):
-    defaults = {"h5file": "../../assets/FlinFlon.geoh5", "objects": "geochem"}
+    defaults = {
+        "h5file": "../../assets/FlinFlon.geoh5",
+        "objects": "geochem",
+        "data": ["Al2O3", "CaO"],
+        "equation": "{NewChannel} = {Al2O3} + numpy.cos({CaO} / numpy.max({CaO}) * numpy.pi)",
+    }
 
     def __init__(self, **kwargs):
 
         kwargs = self.apply_defaults(**kwargs)
-
-        self._add = Button(description=">> Create Variable >>")
-        self._channel = Text("NewChannel", description="Name: ")
+        self.var = {}
+        self.select_multiple = True
+        self._channel = Text(description="Name: ")
         self._equation = Textarea(layout=Layout(width="75%"))
         self._use = Button(description=">> Add Variable >>")
+        self.use.on_click(self.click_use)
 
         super().__init__(**kwargs)
 
-        self._store = ObjectDataSelection()
-        self.store._workspace = self.workspace
-        self.store.objects = self.objects
-        self.store.update_data_list(None)
-        self.store.data.description = "Apply to:"
+        self.trigger.on_click(self.click_trigger)
 
-        def click_add(_):
-            self.click_add()
-
-        def click_use(_):
-            self.click_use()
-
-        def click_trigger(_):
-            self.click_trigger()
-
-        self.use.on_click(click_use)
-        self.add.on_click(click_add)
-        self.trigger.on_click(click_trigger)
-
-        self._widget = VBox(
+        self.data_panel = VBox([self.objects, HBox([self.data, self.use])])
+        self.output_panel = VBox([self.trigger, self.live_link_panel])
+        self._main = VBox(
             [
                 self.project_panel,
-                self.objects,
-                HBox([self.data, self.use]),
-                HBox([self.channel, self.add]),
-                VBox([self.equation, self.store.data], layout=Layout(width="100%"),),
-                self.trigger,
-                self.live_link_panel,
+                self.data_panel,
+                VBox([self.equation], layout=Layout(width="100%"),),
+                self.output_panel,
             ]
         )
-        self.var = {}
 
-    @property
-    def add(self):
-        """
-        ipywidgets.ToggleButton()
-        """
-        if getattr(self, "_add", None) is None:
-            self._add = Button(description=">> Create >>")
-
-        return self._add
-
-    @property
-    def channel(self):
-        """
-        ipywidgets.Text()
-        """
-        if getattr(self, "_channel", None) is None:
-            self._channel = Text("NewChannel", description="Name: ")
-
-        return self._channel
+    def __call__(self):
+        return self.main
 
     @property
     def equation(self):
@@ -91,16 +63,6 @@ class Calculator(ObjectDataSelection):
 
         return self._use
 
-    @property
-    def store(self):
-        """
-        geoapps.selection.ObjectDataSelection()
-        """
-        if getattr(self, "_store", None) is None:
-            self._store = ObjectDataSelection()
-
-        return self._store
-
     @property
     def workspace(self):
         """
@@ -119,51 +81,52 @@ class Calculator(ObjectDataSelection):
         assert isinstance(workspace, Workspace), f"Workspace must of class {Workspace}"
         self._workspace = workspace
         self._h5file = workspace.h5file
-
-        # Refresh the list of objects
         self.update_objects_list()
         self.store._workspace = self.workspace
         self.store.objects = self.objects
         self.store.update_data_list(None)
 
-    def click_add(self):
-        """
-        Add new data property.
-        """
-        obj = self.workspace.get_entity(self.objects.value)[0]
-
-        if getattr(obj, "vertices", None) is not None:
-            new_data = obj.add_data(
-                {self.channel.value: {"values": numpy.zeros(obj.n_vertices)}}
-            )
-        else:
-            new_data = obj.add_data(
-                {self.channel.value: {"values": numpy.zeros(obj.n_cells)}}
-            )
-
-        self.data.options = obj.get_data_list()
-        self.store.data.options = [new_data.name]
-        self.store.data.value = new_data.name
-
-    def click_use(self):
+    def click_use(self, _):
         """
         Add the data channel to the list of variables and expression window
         """
-        name = self.objects.value + "." + self.data.value
-        if name not in self.var.keys():
-            obj = self.workspace.get_entity(self.objects.value)[0]
-            self.var[name] = obj.get_data(self.data.value)[0].values
+        for name in self.data.value:
+            if name not in self.var.keys():
+                obj = self.workspace.get_entity(self.objects.value)[0]
+                self.var[name] = obj.get_data(name)[0].values
 
-        self.equation.value = self.equation.value + "var['" + name + "']"
+            self.equation.value = self.equation.value + "{" + name + "}"
 
-    def click_trigger(self):
+    def click_trigger(self, _):
         """
         Evaluate the expression and output the result to geoh5
         """
         var = self.var
-        vals = eval(self.equation.value)
         obj = self.workspace.get_entity(self.objects.value)[0]
-        data = obj.get_data(self.store.data.value)[0]
+        out_var, equation = re.split("=", self.equation.value)
+
+        out_var = out_var.strip()[1:-1]
+
+        for name in re.findall("{(.*?)}", equation):
+            if name in obj.get_data_list():
+                if name not in list(self.var.keys()):
+                    self.var[name] = obj.get_data(name)[0].values
+            else:
+                print(f"Variable {name} not in object data list. Please revise")
+                return
+
+        if out_var not in obj.get_data_list():
+            if getattr(obj, "vertices", None) is not None:
+                obj.add_data({out_var: {"values": numpy.zeros(obj.n_vertices)}})
+            else:
+                obj.add_data({out_var: {"values": numpy.zeros(obj.n_cells)}})
+
+        equation = re.sub(r"{", "var['", equation)
+        equation = re.sub(r"}", "']", equation).strip()
+        vals = eval(equation)
+
+        data = obj.get_data(out_var)[0]
+        self.var[out_var] = vals
         data.values = vals
 
         if self.live_link.value:
@@ -172,3 +135,11 @@ class Calculator(ObjectDataSelection):
             self.live_link_output(obj)
 
         self.workspace.finalize()
+
+        choice = self.data.value
+        self.data.options = obj.get_data_list()
+        self.data.value = choice
+
+        if self.plot_result:
+            out = plot_plan_data_selection(obj, data)
+            self.figure = out[0].figure
