@@ -116,12 +116,12 @@ class EdgeDetectionApp(PlotSelection2D):
         self.data.observe(update_name, names="value")
         self.update_name()
 
-        self._widget = VBox(
+        self._main = VBox(
             [
                 self.project_panel,
                 HBox(
                     [
-                        VBox([self.widget]),
+                        self.main,
                         VBox(
                             [
                                 self.sigma,
@@ -131,7 +131,7 @@ class EdgeDetectionApp(PlotSelection2D):
                                 self.window_size,
                                 self.compute,
                                 self.export_as,
-                                self.trigger_panel,
+                                self.output_panel,
                             ],
                             layout=Layout(width="50%"),
                         ),
@@ -176,13 +176,6 @@ class EdgeDetectionApp(PlotSelection2D):
         """IntSlider"""
         return self._window_size
 
-    @property
-    def widget(self):
-        """
-        :obj:`ipywidgets.VBox`: Pre-defined application layout
-        """
-        return self._widget
-
     def save_trigger(self):
         entity, _ = self.get_selected_entities()
         if getattr(self.trigger, "vertices", None) is not None:
@@ -237,7 +230,7 @@ class EdgeDetectionApp(PlotSelection2D):
             x = grid.centroids[:, 0].reshape(grid.shape, order="F")
             y = grid.centroids[:, 1].reshape(grid.shape, order="F")
             z = grid.centroids[:, 2].reshape(grid.shape, order="F")
-            grid_data = data.values.reshape(grid.shape, order="F")
+            grid_data = data[0].values.reshape(grid.shape, order="F")
             indices = self.indices
             ind_x, ind_y = (
                 np.any(indices, axis=1),
